%define orthancclientversion 0.8
%define orthancversion 0.8.6


Name:		orthanc
Version:	%{orthancversion}
Release:	1%{?dist}
Summary:	RESTful DICOM server for healthcare and medical research

License:	GPLv3 with exceptions
URL:		https://code.google.com/p/orthanc/
Source0:	https://orthanc.googlecode.com/files/Orthanc-%{version}.tar.gz
Source1:	orthanc.json
Source2:	orthanc.service
Source3:	orthancclient.README

# This patch fixes the installation path of the 64bit version of the
# client library
Patch1:	     	orthanc-%{orthancversion}-lib64.patch

BuildRequires:	cmake >= 2.8.0
BuildRequires:	boost-devel
BuildRequires:	curl-devel
BuildRequires:	dcmtk-devel
BuildRequires:	glog-devel >= 0.3.3
BuildRequires:	gtest-devel
BuildRequires:	help2man
BuildRequires:	libpng-devel
BuildRequires:	libsqlite3x-devel
BuildRequires:	libuuid-devel
BuildRequires:	mongoose-devel
BuildRequires:	openssl-devel
BuildRequires:	python
BuildRequires:	jsoncpp-devel
BuildRequires:	lua-devel >= 5.1.0
BuildRequires:	doxygen
BuildRequires:	systemd
BuildRequires:	pugixml-devel

%if 0%{?fedora} >= 21
# The dependency over gflags is only necessary for rawhide
BuildRequires: gflags-devel
%endif

# The following line is required to add the "orthanc" user and group
Requires(pre):	shadow-utils

# The following lines are required to install the Systemd service
# https://fedoraproject.org/wiki/Packaging:ScriptletSnippets?rd=Packaging/ScriptletSnippets#Macroized_scriptlets_.28Fedora_18.2B.29
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd


%description
Orthanc aims at providing a simple, yet powerful standalone DICOM
server. Orthanc can turn any computer running Windows or Linux into a
DICOM store (in other words, a mini-PACS system). Its architecture is
lightweight, meaning that no complex database administration is
required, nor the installation of third-party dependencies.

What makes Orthanc unique is the fact that it provides a RESTful
API. Thanks to this major feature, it is possible to drive Orthanc
from any computer language. The DICOM tags of the stored medical
images can be downloaded in the JSON file format. Furthermore,
standard PNG images can be generated on-the-fly from the DICOM
instances by Orthanc.

Orthanc lets its users focus on the content of the DICOM files,
hiding the complexity of the DICOM format and of the DICOM protocol.


%package -n orthancclient-lib
Summary:        Orthanc Client library
Group:          System/Libraries

%description -n orthancclient-lib
Orthanc Client is a library to access the content of a remote instance
of Orthanc. Orthanc is a lightweight, RESTful DICOM server for
healthcare and medical research.

%package -n orthancclient-devel
Summary:        Header files for Orthanc Client library
Group:          Development/Libraries/C and C++
Requires:	orthancclient-lib = %{version}-%{release}
Requires:	cmake >= 2.8.0
Requires:	boost
Requires:	curl
Requires:	libpng
Requires:	openssl
Requires:	jsoncpp

%description -n orthancclient-devel
This package contains the development and header files for the Orthanc
Client library.


%package -n orthancclient-doc
Summary:        Documentation files for Orthanc Client library
Group:          Documentation
BuildArch:	noarch

%description -n orthancclient-doc
This package contains the API document of the Orthanc Client library,
and sample codes.



%prep
%setup -q -n Orthanc-%{version}
%patch1

# Copy the configuration file and the Systemd Service for the Orthanc server
cp -p %SOURCE1 orthanc.json
cp -p %SOURCE2 orthanc.service
cp -p %SOURCE3 orthancclient.README


%build
%cmake	-DSTATIC_BUILD:BOOL=OFF \
	-DSTANDALONE_BUILD:BOOL=ON \
	-DCMAKE_BUILD_TYPE=Release \
	-DDCMTK_LIBRARIES=CharLS \
	-DUNIT_TESTS_WITH_HTTP_CONNEXIONS=OFF \
	-DSYSTEM_MONGOOSE_USE_CALLBACKS=OFF \
	.

make %{?_smp_mflags}

# Generate the man page
help2man ./Orthanc -N -n "Lightweight, RESTful DICOM server for healthcare and medical research" > Orthanc.1


%check
# Execute the unit tests
./UnitTests


%install
make install DESTDIR=%{buildroot}

install -m 755 -d %{buildroot}%{_mandir}/man1
cp Orthanc.1 %{buildroot}%{_mandir}/man1

install -m 755 -d %{buildroot}%{_sysconfdir}/orthanc
cp orthanc.json %{buildroot}%{_sysconfdir}/orthanc

install -m 755 -d %{buildroot}%{_unitdir}
cp orthanc.service %{buildroot}%{_unitdir}

install -m 755 -d %{buildroot}%{_sharedstatedir}/orthanc/db-v3

# Copy the Doxgen documentation of Orthanc Client
mv %{buildroot}%{_docdir}/orthanc %{buildroot}%{_docdir}/orthancclient-%{orthancversion}

# README file for the Orthanc Client
cp orthancclient.README %{buildroot}%{_docdir}/orthancclient-%{orthancversion}/README

# Copy sample codes for the Orthanc Client
cp -r Resources/Samples/OrthancClient %{buildroot}%{_docdir}/orthancclient-%{orthancversion}/Samples


%files
%doc NEWS README THANKS COPYING
%{_mandir}/man1/*.1*
%{_sbindir}/*
%{_unitdir}/orthanc.service

%dir %{_sysconfdir}/orthanc
%config(noreplace) %{_sysconfdir}/orthanc/orthanc.json
%dir %attr(0755, orthanc, orthanc) %{_sharedstatedir}/orthanc
%dir %attr(0755, orthanc, orthanc) %{_sharedstatedir}/orthanc/db-v3


%files -n orthancclient-lib
%defattr(-,root,root,-)
%{_libdir}/*.so.*


%files -n orthancclient-devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_libdir}/*.so


%files -n orthancclient-doc
%defattr(-,root,root,-)
%{_docdir}/orthancclient-%{orthancversion}/*



# Installation of the Systemd Orthanc service
# https://fedoraproject.org/wiki/Packaging:ScriptletSnippets#Systemd
%post
%systemd_post orthanc.service

%preun
%systemd_preun orthanc.service

%postun
%systemd_postun_with_restart orthanc.service


%pre
# http://fedoraproject.org/wiki/Packaging%3aUsersAndGroups
# "We never remove users or groups created by packages"

getent group orthanc >/dev/null || groupadd -r orthanc
getent passwd orthanc >/dev/null || \
    useradd -r -g orthanc -G orthanc -d %{_sharedstatedir}/orthanc -s /sbin/nologin \
    -c "User account that holds information for Orthanc" orthanc
exit 0


%changelog
* Wed Apr 8 2015 Mario Ceresa <mrceresa@gmail.com> 0.8.6-1
- New upstrean version

* Mon Jan 26 2015 Petr Machata <pmachata@redhat.com> - 0.8.5-3
- Rebuild for boost 1.57.0


* Tue Dec 16 2014 Mario Ceresa <mrceresa@gmail.com> 0.8.5-2
- Rebuild for dcmtk update

* Tue Nov  4 2014 Sebastien Jodogne <s.jodogne@gmail.com> 0.8.5-1
- New upstream version

* Fri Sep 12 2014 Sebastien Jodogne <s.jodogne@gmail.com> 0.8.3-1
- New upstream version

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jul 11 2014 Sebastien Jodogne <s.jodogne@gmail.com> 0.8.0-1
- New upstream version

* Thu Jun 12 2014 Sebastien Jodogne <s.jodogne@gmail.com> 0.7.6-1
- New upstream version

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu May 22 2014 Petr Machata <pmachata@redhat.com> - 0.7.5-2
- Rebuild for boost 1.55.0

* Fri May  9 2014 Sebastien Jodogne <s.jodogne@gmail.com> 0.7.5-1
- New upstream version

* Fri Feb 14 2014 Sebastien Jodogne <s.jodogne@gmail.com> 0.7.3-1
- New upstream version

* Fri Nov  8 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.7.2-1
- New upstream version

* Wed Oct 30 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.7.1-1
- New upstream version
- Fix for big endian architectures (bug #985748)
- Packaging of the Orthanc Client library

* Mon Sep 16 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.6.1-1
- New upstream version

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 27 2013 pmachata@redhat.com - 0.6.0-2
- Rebuild for boost 1.54.0

* Tue Jul 16 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.6.0-1
- New upstream version

* Wed May  8 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.5.2-1
- New upstream version

* Wed Apr 17 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.5.1-1
- New upstream version

* Thu Apr 04 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.5.0-1
- New upstream version

* Wed Dec 19 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-5
- Fixes according to reviews

* Wed Dec 19 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-4
- Dynamic linking against mongoose-lib

* Wed Dec 19 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-3
- Improvements to the packaging

* Tue Dec 18 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-2
- Improvements to the packaging

* Mon Dec 17 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-1
- Initial RPM Release
